@@ -20,24 +20,13 @@ import copy
 import functools
 import itertools
 import sys
+import types
+import unittest
 import warnings
 
-from extras import (
-    safe_hasattr,
-    try_import,
-    try_imports,
-    )
-# To let setup.py work, make this a conditional import.
-unittest = try_imports(['unittest2', 'unittest'])
-import six
-
-from testtools import (
-    content,
-    )
-from testtools.compat import (
-    advance_iterator,
-    reraise,
-    )
+from testtools.compat import reraise
+from testtools import content
+from testtools.helpers import try_import
 from testtools.matchers import (
     Annotate,
     Contains,
@@ -54,19 +43,16 @@ from testtools.monkey import patch
 from testtools.runtest import (
     MultipleExceptions,
     RunTest,
-    )
+)
 from testtools.testresult import (
     ExtendedToOriginalDecorator,
     TestResult,
-    )
-
-wraps = try_import('functools.wraps')
+)
 
 
 class TestSkipped(Exception):
     """Raised within TestCase.run() when a test is skipped."""
 TestSkipped = try_import('unittest.case.SkipTest', TestSkipped)
-TestSkipped = try_import('unittest2.case.SkipTest', TestSkipped)
 
 
 class _UnexpectedSuccess(Exception):
@@ -77,20 +63,16 @@ class _UnexpectedSuccess(Exception):
     """
 _UnexpectedSuccess = try_import(
     'unittest.case._UnexpectedSuccess', _UnexpectedSuccess)
-_UnexpectedSuccess = try_import(
-    'unittest2.case._UnexpectedSuccess', _UnexpectedSuccess)
 
 
 class _ExpectedFailure(Exception):
-    """An expected failure occured.
+    """An expected failure occurred.
 
     Note that this exception is private plumbing in testtools' testcase
     module.
     """
 _ExpectedFailure = try_import(
     'unittest.case._ExpectedFailure', _ExpectedFailure)
-_ExpectedFailure = try_import(
-    'unittest2.case._ExpectedFailure', _ExpectedFailure)
 
 
 # Copied from unittest before python 3.4 release. Used to maintain
@@ -178,7 +160,7 @@ def gather_details(source_dict, target_dict):
         new_name = name
         disambiguator = itertools.count(1)
         while new_name in target_dict:
-            new_name = '%s-%d' % (name, advance_iterator(disambiguator))
+            new_name = '%s-%d' % (name, next(disambiguator))
         name = new_name
         target_dict[name] = _copy_content(content_object)
 
@@ -199,9 +181,9 @@ def _mods(i, mod):
 
 
 def _unique_text(base_cp, cp_range, index):
-    s = six.text_type('')
+    s = ''
     for m in _mods(index, cp_range):
-        s += six.unichr(base_cp + m)
+        s += chr(base_cp + m)
     return s
 
 
@@ -213,7 +195,7 @@ def unique_text_generator(prefix):
 
     :param prefix: The prefix for text.
     :return: text that looks like '<prefix>-<text_with_unicode>'.
-    :rtype: six.text_type
+    :rtype: str
     """
     # 0x1e00 is the start of a range of glyphs that are easy to see are
     # unicode since they've got circles and dots and other diacriticals.
@@ -223,7 +205,7 @@ def unique_text_generator(prefix):
     index = 0
     while True:
         unique_text = _unique_text(BASE_CP, CP_RANGE, index)
-        yield six.text_type('%s-%s') % (prefix, unique_text)
+        yield '{}-{}'.format(prefix, unique_text)
         index = index + 1
 
 
@@ -254,7 +236,7 @@ class TestCase(unittest.TestCase):
             ``TestCase.run_tests_with`` if given.
         """
         runTest = kwargs.pop('runTest', None)
-        super(TestCase, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._reset()
         test_method = self._get_test_method()
         if runTest is None:
@@ -296,7 +278,7 @@ class TestCase(unittest.TestCase):
 
     def __repr__(self):
         # We add id to the repr because it makes testing testtools easier.
-        return "<%s id=0x%0x>" % (self.id(), id(self))
+        return "<{} id=0x{:0x}>".format(self.id(), id(self))
 
     def addDetail(self, name, content_object):
         """Add a detail to be reported with this test's outcome.
@@ -391,7 +373,7 @@ class TestCase(unittest.TestCase):
         the exception has caused.
 
         Handlers are called in first-added, first-called order, and if they
-        raise an exception, that will propogate out of the test running
+        raise an exception, that will propagate out of the test running
         machinery, halting test processing. As a result, do not call code that
         may unreasonably fail.
         """
@@ -469,12 +451,12 @@ class TestCase(unittest.TestCase):
            deemed to have suffered an error, exactly as for an
            unexpected exception.
         """
-        class ReRaiseOtherTypes(object):
+        class ReRaiseOtherTypes:
             def match(self, matchee):
                 if not issubclass(matchee[0], excClass):
                     reraise(*matchee)
 
-        class CaptureMatchee(object):
+        class CaptureMatchee:
             def match(self, matchee):
                 self.matchee = matchee[1]
         capture = CaptureMatchee()
@@ -497,6 +479,7 @@ class TestCase(unittest.TestCase):
         if mismatch_error is not None:
             raise mismatch_error
 
+    assertItemsEqual = unittest.TestCase.assertCountEqual
     def addDetailUniqueName(self, name, content_object):
         """Add a detail to the test, but ensure it's name is unique.
 
@@ -593,7 +576,7 @@ class TestCase(unittest.TestCase):
         Use this when you need an arbitrary integer in your test, or as a
         helper for custom anonymous factory methods.
         """
-        return advance_iterator(self._unique_id_gen)
+        return next(self._unique_id_gen)
 
     def getUniqueString(self, prefix=None):
         """Get a string unique to this test.
@@ -646,7 +629,7 @@ class TestCase(unittest.TestCase):
         id_gen = self._traceback_id_gens.setdefault(
             tb_label, itertools.count(0))
         while True:
-            tb_id = advance_iterator(id_gen)
+            tb_id = next(id_gen)
             if tb_id:
                 tb_label = '%s-%d' % (tb_label, tb_id)
             if tb_label not in self.getDetails():
@@ -742,8 +725,10 @@ class TestCase(unittest.TestCase):
                 # the fixture.  Ideally this whole try/except is not
                 # really needed any more, however, we keep this code to
                 # remain compatible with the older setUp().
-                if (safe_hasattr(fixture, '_details') and
-                        fixture._details is not None):
+                if (
+                    hasattr(fixture, '_details') and
+                    fixture._details is not None
+                ):
                     gather_details(fixture.getDetails(), self.getDetails())
             except:
                 # Report the setUp exception, then raise the error during
@@ -761,7 +746,7 @@ class TestCase(unittest.TestCase):
             return fixture
 
     def setUp(self):
-        super(TestCase, self).setUp()
+        super().setUp()
         if self.__setup_called:
             raise ValueError(
                 "In File: %s\n"
@@ -772,7 +757,7 @@ class TestCase(unittest.TestCase):
         self.__setup_called = True
 
     def tearDown(self):
-        super(TestCase, self).tearDown()
+        super().tearDown()
         if self.__teardown_called:
             raise ValueError(
                 "In File: %s\n"
@@ -783,7 +768,7 @@ class TestCase(unittest.TestCase):
         self.__teardown_called = True
 
 
-class PlaceHolder(object):
+class PlaceHolder:
     """A placeholder test.
 
     `PlaceHolder` implements much of the same interface as TestCase and is
@@ -822,7 +807,7 @@ class PlaceHolder(object):
         internal = [self._outcome, self._test_id, self._details]
         if self._short_description is not None:
             internal.append(self._short_description)
-        return "<%s.%s(%s)>" % (
+        return "<{}.{}({})>".format(
             self.__class__.__module__,
             self.__class__.__name__,
             ", ".join(map(repr, internal)))
@@ -912,14 +897,14 @@ def attr(*args):
         alter its id to enumerate the added attributes.
     """
     def decorate(fn):
-        if not safe_hasattr(fn, '__testtools_attrs'):
+        if not hasattr(fn, '__testtools_attrs'):
             fn.__testtools_attrs = set()
         fn.__testtools_attrs.update(args)
         return fn
     return decorate
 
 
-class WithAttributes(object):
+class WithAttributes:
     """A mix-in class for modifying test id by attributes.
 
     e.g.
@@ -932,7 +917,7 @@ class WithAttributes(object):
     """
 
     def id(self):
-        orig = super(WithAttributes, self).id()
+        orig = super().id()
         # Depends on testtools.TestCase._get_test_method, be nice to support
         # plain unittest.
         fn = self._get_test_method()
@@ -942,6 +927,12 @@ class WithAttributes(object):
         return orig + '[' + ','.join(sorted(attributes)) + ']'
 
 
+class_types = [type]
+if getattr(types, 'ClassType', None) is not None:
+    class_types.append(types.ClassType)
+class_types = tuple(class_types)
+
+
 def skip(reason):
     """A decorator to skip unit tests.
 
@@ -950,20 +941,19 @@ def skip(reason):
     @unittest.skip decorator.
     """
     def decorator(test_item):
+        if not isinstance(test_item, class_types):
+            @functools.wraps(test_item)
+            def skip_wrapper(*args, **kwargs):
+                raise TestCase.skipException(reason)
+            test_item = skip_wrapper
+
         # This attribute signals to RunTest._run_core that the entire test
         # must be skipped - including setUp and tearDown. This makes us
         # compatible with testtools.skip* functions, which set the same
         # attributes.
         test_item.__unittest_skip__ = True
         test_item.__unittest_skip_why__ = reason
-        if wraps is not None:
-            @wraps(test_item)
-            def skip_wrapper(*args, **kwargs):
-                raise TestCase.skipException(reason)
-        else:
-            def skip_wrapper(test_item):
-                test_item.skip(reason)
-        return skip_wrapper
+        return test_item
     return decorator
 
 
@@ -1033,7 +1023,7 @@ class ExpectedException:
         return True
 
 
-class Nullary(object):
+class Nullary:
     """Turn a callable into a nullary callable.
 
     The advantage of this over ``lambda: f(*args, **kwargs)`` is that it
@@ -1052,7 +1042,7 @@ class Nullary(object):
         return repr(self._callable_object)
 
 
-class DecorateTestCaseResult(object):
+class DecorateTestCaseResult:
     """Decorate a TestCase and permit customisation of the result for runs."""
 
     def __init__(self, case, callout, before_run=None, after_run=None):
